PerSkinData

Struct PerSkinData 

pub struct PerSkinData {
    pub node_to_joint_idx: FastHashMap<NodeIndex, JointIndex>,
    pub joint_nodes_topological_order: Vec<NodeIndex>,
    pub skeletons: Vec<SkeletonHandle>,
}
Cached data structures per each of the Skins in a gltf model. This struct is part of AnimationData

Fields

node_to_joint_idx: FastHashMap<NodeIndex, JointIndex>

Translates node indices to joint indices for this particular skin. This translation is necessary because an animation may be animating a scene node which is present in multiple skins.

joint_nodes_topological_order: Vec<NodeIndex>

Stores the node indices for this skin’s joints in topological order. This is used to avoid iterating all the scene hierarchy when computing global positions for a node.

skeletons: Vec<SkeletonHandle>

The list of skeletons deformed by this animation. There’s one skeleton for each of the mesh primitives. Every skeleton in this list is shares the same bone structure.